==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring.md <==
# AmazonVpcTrafficMirroring


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')
```



| Illustration | AmazonVpcTrafficMirroring | AmazonVpcTrafficMirroringCard | AmazonVpcTrafficMirroringGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring.png) | ![illustration for AmazonVpcTrafficMirroring](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring.Local.png) | ![illustration for AmazonVpcTrafficMirroringCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroringCard.Local.png) | ![illustration for AmazonVpcTrafficMirroringGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroringGroup.Local.png) |




## AmazonVpcTrafficMirroring

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroring
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroring('AmazonVpcTrafficMirroring', 'Amazon Vpc Traffic Mirroring', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroring
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroring('AmazonVpcTrafficMirroring', 'Amazon Vpc Traffic Mirroring', 'an optional tech label')
@enduml
```

## AmazonVpcTrafficMirroringCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroringCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroringCard('AmazonVpcTrafficMirroringCard', 'Amazon Vpc Traffic Mirroring Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroringCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroringCard('AmazonVpcTrafficMirroringCard', 'Amazon Vpc Traffic Mirroring Card', 'an optional description')
@enduml
```

## AmazonVpcTrafficMirroringGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroringGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroringGroup('AmazonVpcTrafficMirroringGroup', 'Amazon Vpc Traffic Mirroring Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroringGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroringGroup('AmazonVpcTrafficMirroringGroup', 'Amazon Vpc Traffic Mirroring Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring.md <==
# AmazonVpcTrafficMirroring


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')
```



| Illustration | AmazonVpcTrafficMirroring | AmazonVpcTrafficMirroringCard | AmazonVpcTrafficMirroringGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring.png) | ![illustration for AmazonVpcTrafficMirroring](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring.Local.png) | ![illustration for AmazonVpcTrafficMirroringCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroringCard.Local.png) | ![illustration for AmazonVpcTrafficMirroringGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroringGroup.Local.png) |




## AmazonVpcTrafficMirroring

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroring
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroring('AmazonVpcTrafficMirroring', 'Amazon Vpc Traffic Mirroring', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroring
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroring('AmazonVpcTrafficMirroring', 'Amazon Vpc Traffic Mirroring', 'an optional tech label')
@enduml
```

## AmazonVpcTrafficMirroringCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroringCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroringCard('AmazonVpcTrafficMirroringCard', 'Amazon Vpc Traffic Mirroring Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroringCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroringCard('AmazonVpcTrafficMirroringCard', 'Amazon Vpc Traffic Mirroring Card', 'an optional description')
@enduml
```

## AmazonVpcTrafficMirroringGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroringGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroringGroup('AmazonVpcTrafficMirroringGroup', 'Amazon Vpc Traffic Mirroring Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonVpcTrafficMirroringGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonVpcTrafficMirroring')

' renders the element
AmazonVpcTrafficMirroringGroup('AmazonVpcTrafficMirroringGroup', 'Amazon Vpc Traffic Mirroring Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
